Update of /cvsroot/monetdb/pathfinder/compiler/debug
In directory sc8-pr-cvs16.sourceforge.net:/tmp/cvs-serv5765/debug
Modified Files:
logdebug.c physdebug.c
Log Message:
-- Split up the required distribution value property as it
checked the order AND the consistent mapping of values at once.
The two new properties now separately check for the required order columns
and for columns whose values have to conform to a bijective mapping.
Index: logdebug.c
===================================================================
RCS file: /cvsroot/monetdb/pathfinder/compiler/debug/logdebug.c,v
retrieving revision 1.86
retrieving revision 1.87
diff -u -d -r1.86 -r1.87
--- logdebug.c 11 Jan 2008 12:49:09 -0000 1.86
+++ logdebug.c 14 Jan 2008 14:03:27 -0000 1.87
@@ -1041,13 +1041,25 @@
}
}
fst = true;
/* list distribution columns */
for (unsigned int i = 0; i < n->schema.count; i++) {
PFalg_att_t att = n->schema.items[i].name;
- if (PFprop_req_distr_col (n->prop, att)) {
+ if (PFprop_req_order_col (n->prop, att)) {
PFarray_printf (
dot,
- fst ? "\\ndistr col: %s" : ", %s",
+ fst ? "\\norder col: %s" : ", %s",
+ PFatt_str (att));
+ fst = false;
+ }
+ }
+ fst = true;
+ /* list bijective columns */
+ for (unsigned int i = 0; i < n->schema.count; i++) {
+ PFalg_att_t att = n->schema.items[i].name;
+ if (PFprop_req_bijective_col (n->prop, att)) {
+ PFarray_printf (
+ dot,
+ fst ? "\\nbijective col: %s" : ", %s",
PFatt_str (att));
fst = false;
}
@@ -1041,13 +1041,25 @@
}
fst = true;
- /* list distribution columns */
+ /* list order columns */
for (unsigned int i = 0; i < n->schema.count; i++) {
PFalg_att_t att = n->schema.items[i].name;
Index: physdebug.c
===================================================================
RCS file: /cvsroot/monetdb/pathfinder/compiler/debug/physdebug.c,v
retrieving revision 1.49
retrieving revision 1.50
diff -u -d -r1.49 -r1.50
--- physdebug.c 11 Jan 2008 12:49:09 -0000 1.49
+++ physdebug.c 14 Jan 2008 14:03:28 -0000 1.50
@@ -874,13 +874,25 @@
}
}
fst = true;
/* list distribution columns */
for (unsigned int i = 0; i < n->schema.count; i++) {
PFalg_att_t att = n->schema.items[i].name;
- if (PFprop_req_distr_col (n->prop, att)) {
+ if (PFprop_req_order_col (n->prop, att)) {
PFarray_printf (
dot,
- fst ? "\\ndistr col: %s" : ", %s",
+ fst ? "\\norder col: %s" : ", %s",
+ PFatt_str (att));
+ fst = false;
+ }
+ }
+ fst = true;
+ /* list bijective columns */
+ for (unsigned int i = 0; i < n->schema.count; i++) {
+ PFalg_att_t att = n->schema.items[i].name;
+ if (PFprop_req_bijective_col (n->prop, att)) {
+ PFarray_printf (
+ dot,
+ fst ? "\\nbijective col: %s" : ", %s",
PFatt_str (att));
fst = false;
}
-------------------------------------------------------------------------
Check out the new SourceForge.net Marketplace.
It's the best place to buy or sell services for
just about anything Open Source.
@@ -874,13 +874,25 @@
}
fst = true;
- /* list distribution columns */
+ /* list order columns */
for (unsigned int i = 0; i < n->schema.count; i++) {
PFalg_att_t att = n->schema.items[i].name;
http://ad.doubleclick.net/clk;164216239;13503038;w?http://sf.net/marketplace
_______________________________________________
Monetdb-pf-checkins mailing list
[email protected]
https://lists.sourceforge.net/lists/listinfo/monetdb-pf-checkins